@@ -13,10 +13,24 @@ use AWS::S3::ResponseParser;
 use AWS::S3::Owner;
 use AWS::S3::Bucket;
 
-our $VERSION = '0.051';
+our $VERSION = '1.00';
 
 has [qw/access_key_id secret_access_key/] => ( is => 'ro', isa => 'Str' );
 
+has 'session_token' => (
+    is      => 'ro',
+    isa     => 'Maybe[Str]',
+    lazy    => 1,
+    default => sub { $ENV{AWS_SESSION_TOKEN} },
+);
+
+has 'region' => (
+    is      => 'ro',
+    isa     => 'Maybe[Str]',
+    lazy    => 1,
+    default => sub { $ENV{AWS_REGION} },
+);
+
 has 'secure' => (
     is      => 'ro',
     isa     => 'Bool',
@@ -28,7 +42,15 @@ has 'endpoint' => (
     is      => 'ro',
     isa     => 'Str',
     lazy    => 1,
-    default => sub { 's3.amazonaws.com' },
+    default => sub {
+        my ( $s ) = @_;
+
+        if ( my $region = $s->region ) {
+            return "s3.$region.amazonaws.com"
+        } else {
+            return "s3.amazonaws.com"
+        }
+    },
 );
 
 has 'ua' => (
@@ -37,6 +59,12 @@ has 'ua' => (
     default => sub { LWP::UserAgent::Determined->new }
 );
 
+has 'honor_leading_slashes' => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => sub { 0 },
+);
+
 sub request {
     my ( $s, $type, %args ) = @_;
 
@@ -91,7 +119,15 @@ sub add_bucket {
     my ( $s, %args ) = @_;
 
     my $type     = 'CreateBucket';
-    my $request  = $s->request( $type, bucket => $args{name}, location => $args{location} );
+    my $request  = $s->request(
+        $type,
+        bucket => $args{name},
+        (
+            $args{location} ? ( location => $args{location} )
+                : $s->region ? ( location => $s->region )
+                : ()
+        ),
+    );
     my $response = $request->request();
 
     if ( my $msg = $response->friendly_error() ) {
@@ -122,6 +158,9 @@ AWS::S3 - Lightweight interface to Amazon S3 (Simple Storage Service)
   my $s3 = AWS::S3->new(
     access_key_id     => 'E654SAKIASDD64ERAF0O',
     secret_access_key => 'LgTZ25nCD+9LiCV6ujofudY1D6e2vfK0R4GLsI4H',
+    session_token     => 'IQob3JpJZ2luXJ2VjJEL7//////////wE...',
+    region            => 'eu-west-1', # set to relevant AWS region
+    honor_leading_slashes => 0, # set to allow leading slashes in bucket names, defaults to 0
   );
 
   # Add a bucket:
@@ -237,6 +276,11 @@ Optional.  Should be an instance of L<LWP::UserAgent> or a subclass of it.
 
 Defaults to creating a new instance of L<LWP::UserAgent::Determined>
 
+=head2 honor_leading_slashes
+
+Optional. Boolean to set if bucket names should include any leading slashes
+when sent to S3 - defaults to zero
+
 =head1 PUBLIC PROPERTIES
 
 =head2 access_key_id
@@ -275,9 +319,10 @@ Returns the L<AWS::S3::Bucket> object matching C<$name> if found.
 
 Returns nothing otherwise.
 
-=head2 add_bucket( name => $name )
+=head2 add_bucket( name => $name, location => 'us-west-1' )
 
-Attempts to create a new bucket with the name provided.
+Attempts to create a new bucket with the name provided. The location parameter is optional
+and, as per the AWS docs, will default to "us-east-1".
 
 On success, returns the new L<AWS::S3::Bucket>
 
@@ -300,8 +345,9 @@ L<AWS::S3::Owner>
 =head1 AUTHOR
 
 Originally John Drago C<jdrago_999@yahoo.com>, currently maintained by Lee Johnson (LEEJO) C<leejo@cpan.org>
+with contributions from Evan Carroll, Robin Clarke, Ulrich Kautz, simbabque, Dave Rolsky
 
-=head1 LICENSE AND COPYRIGHT
+=head1 LICENSE
 
 This software is Free software and may be used and redistributed under the same
 terms as any version of perl itself.
