@@ -161,13 +161,24 @@ sub _set_contents {
 
 sub signed_url {
     my $s       = shift;
-    my $expires = shift || time + 3600;
+    my $expires = shift || 3600;
+
+    # expiry for v4 signature is in seconds, not epoch time
+    if ( $expires > time ) {
+        $expires -= time;
+    }
+
+	my $key = $s->key;
+
+	if ( ! $s->bucket->s3->honor_leading_slashes ) {
+		$key =~ s!^/!!;
+	}
 
     my $type = "GetPreSignedUrl";
     my $uri  = $s->bucket->s3->request(
         $type,
         bucket  => $s->bucket->name,
-        key     => $s->key,
+        key     => $key,
         expires => $expires,
     )->request;
 
@@ -320,7 +331,10 @@ Update contents and/or contenttype of the file.
 =head2 signed_url( $expiry_time )
 
 Will return a signed URL for public access to the file. $expiry_time should be a
-Unix seconds since epoch, and will default to now + 1 hour is not passed
+Unix seconds since epoch, and will default to now + 1 hour is not passed.
+
+Note that the Signature parameter value will be URI encoded to prevent reserved
+characters (+, =, etc) causing a bad request.
 
 =head1 SEE ALSO
 
